
#line 3 "lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 34
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 * Given that the standard has decreed that size_t exists since 1989,
 * I guess we can afford to depend on it. Manoj.
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 233
#define YY_END_OF_BUFFER 234
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[738] =
    {   0,
       41,   41,   41,   41,    0,    0,   79,   79,   89,   89,
       82,   82,   57,   57,    0,    0,   71,   71,    0,    0,
        0,    0,  234,  232,   41,    1,    2,  232,  232,  232,
      232,  230,   39,   46,   38,  231,  231,  231,  231,  231,
      231,  231,  231,  231,  231,  231,  231,  231,  231,  231,
      231,  231,  231,   50,  232,   41,  228,  231,  233,   41,
        2,  233,  233,  233,   46,   56,   56,   56,   56,   56,
       56,   56,   56,   50,  233,   78,   78,    2,   78,   81,
       79,    2,   80,   81,   89,  213,  212,  233,  233,  233,
      233,  233,  233,  233,  233,  214,   86,   82,    2,   84,

       85,   83,   86,   63,   57,    2,   60,   62,   61,   63,
       63,   68,   68,    2,   68,   68,   68,   68,   71,   77,
       74,  233,  233,  233,  229,  229,    2,  229,   88,   88,
        2,   87,   88,   41,    0,    0,   45,   40,    0,   44,
        0,   43,   46,  231,  231,  231,  231,  231,   42,  231,
      231,   47,  231,   34,  231,  231,  231,  231,  231,  231,
      231,  231,  231,  231,  231,  231,  231,  231,  231,  231,
        0,  231,  231,   48,    0,  215,    0,   41,    0,   40,
      228,   40,   42,  220,  219,   41,    0,   56,   56,   47,
       56,   53,   56,   56,   48,    0,   79,   89,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   82,   57,    0,    0,    0,   65,   64,    0,
        0,   67,    0,   66,    0,   70,   69,   71,   74,    0,
       75,   76,    0,  224,  223,   26,  231,  231,  231,  231,
      231,  231,  231,  231,  231,  231,  231,  231,  231,  231,
      231,  231,  231,  231,  231,  231,  231,   32,  231,  231,
      231,  231,  231,   49,   24,  231,  231,  216,  225,  228,
      228,  228,    0,  222,  221,   56,   56,   55,   56,  100,
        0,    0,    0,  103,  104,  105,  106,  107,  108,  109,
      110,  111,  112,  113,  114,  115,  116,  117,  118,  119,

      120,  121,  122,  123,  124,  125,  126,  127,  128,  129,
      130,  131,  132,  133,  134,  135,  136,  137,  138,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   59,
       58,    0,    0,   73,   72,    0,    0,  231,   28,  231,
      231,   36,  231,  231,  231,  231,  231,  231,  231,  231,
      231,  231,  231,  231,  231,    3,  231,  231,   21,  231,
      231,  231,  231,  231,  231,  228,  228,   51,   56,   54,
        0,   91,    0,   99,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  180,  181,  182,  183,  184,  185,
      186,  187,  188,  211,  211,  211,  211,  211,  211,  211,

      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  157,   93,    0,    0,    0,   97,    0,    0,
        0,  210,    0,   64,    0,    0,  217,    0,  231,   19,
      231,    0,  231,  231,  231,  231,  231,  231,   22,  231,
       29,  231,  231,   31,  231,  231,  231,  231,  231,  231,
       20,  231,  231,  231,  228,  227,   56,   97,    0,  207,
      211,  211,  211,  211,  211,  211,  208,  211,  162,  211,
      211,  154,  189,  190,  191,  192,  193,  194,  195,  196,
      197,  198,  199,  200,  201,  202,  203,  211,  211,  163,
      211,  211,  170,  171,  172,  173,  174,  175,  176,  177,

      178,  179,  211,  211,  211,  211,  211,  209,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  150,
       92,    0,   95,   96,    0,   98,    0,   65,   64,  218,
       16,    0,    4,    0,    0,  231,  231,  231,  231,  231,
      231,    5,  231,    8,  231,  231,  231,   27,   35,    0,
      231,   37,    0,  231,  228,  227,   56,    0,  211,  211,
      149,  206,  211,  211,  211,  159,  211,  211,  155,  211,
      211,  156,  211,  211,  211,  211,  211,  211,  211,  211,
      161,  160,  211,  211,  211,  211,  211,  211,  211,   90,
       94,   65,    0,    0,    4,    4,    0,    0,  231,    0,

      231,   25,  231,   33,  231,  231,   13,  231,   30,    0,
      231,    0,    6,  226,   52,   99,  211,  211,  144,  140,
      211,  151,  145,  211,  146,  168,  211,  211,  211,  211,
      211,  152,  211,  102,  148,  158,  211,  204,  143,  101,
        0,    0,    0,    0,  231,  231,  231,  231,    7,  231,
        0,  231,    0,  226,  211,  211,  211,  141,  211,  166,
      211,  165,  211,  142,  153,    0,    0,    0,    0,  231,
      231,   12,  231,    0,  231,    0,  231,    0,  139,  147,
      205,  167,  169,  164,   17,    0,    0,    0,  231,   10,
      231,    0,  231,    0,  231,   23,    0,    0,   10,    0,

      231,    0,  231,    0,  231,    0,    0,  231,    0,    0,
      231,    0,  231,    0,  231,    0,  231,   18,    0,    9,
        0,  231,    0,  231,    0,  231,    9,    0,   15,    0,
       14,    0,   11,   15,   14,   11,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    1,    7,    1,    1,    8,    9,
       10,    1,   11,   12,    1,   13,    1,   14,   15,   16,
       17,   18,   19,   20,   21,   22,   23,   24,    1,    1,
        1,   25,    1,    1,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   45,   46,   47,   48,   49,   50,   51,
       52,   53,   54,    1,   55,    1,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   71,   72,   73,   74,   75,   76,   77,   78,   79,
       80,   81,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[82] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    4,    1,    3,    3,    3,    3,    3,
        3,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    1,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5
    } ;

static yyconst flex_int16_t yy_base[766] =
    {   0,
        0,   77,  135,    0,  215,  219,  223,  227,  279,  357,
      236,  247,  435,  492,  258,  289,  549,    0,  322,  336,
      628,  683,  718, 1953,  308, 1953, 1953,  700,    0,  697,
      601, 1953, 1953,   71, 1953,   54,   64,  294,  725,   38,
        0,   52,   56,   58,   73,  317,  328,   55,   72,  324,
      275,   73,  778, 1953,  104,  377,  211,  463, 1953,  386,
     1953,  585,  577,  508,  100,    0,   74,  253,  826,  197,
      198,  493,  879, 1953,  414, 1953,  441, 1953,  457, 1953,
      472, 1953, 1953,  468,  473, 1953, 1953,  241,  352,  437,
      499,  251,  500,  281,  285, 1953, 1953,  474, 1953, 1953,

     1953, 1953,  478, 1953,  532, 1953, 1953, 1953, 1953,  301,
      482, 1953,  584, 1953,  441,  437,  107,  519,  534, 1953,
      599,  365,  640,    0, 1953,  619, 1953,  544, 1953,  620,
     1953, 1953,  577,  621,  591,  422,  415, 1953,  401,  399,
      366,  361,  650,    0,  340,  350,  613,  358, 1953,  534,
      605,  667,  386,    0,  401,  489,  497,  547,  680,  552,
      628,  668,  661,  712,  664,  659,  676,  688,  683,  690,
        0,  752,  683,    0,  707, 1953,  352,  760,  711,  307,
     1953,  743,  766, 1953, 1953,  761,  427,    0,  742,  754,
      757,    0,  784,  777,    0,  822,  826,  827,  778,  789,

      794,  814,  927,  821,  814,  828,  847,  837,  836,  849,
      849,  257,  862,  923,  250,  326, 1007, 1953,  377,  772,
      298,  296,  290,  282,  487, 1953,  513,  924,  999,  537,
     1007,    0,  235, 1953, 1953,    0,  998,  991,  999,  996,
      999,  993,  993,  989, 1011, 1002,  996, 1007, 1014, 1013,
     1006, 1019, 1004, 1011, 1020, 1025, 1026,    0, 1009, 1008,
     1024, 1013, 1012,    0,    0, 1019, 1015, 1953,  222,  247,
     1066, 1067,  866, 1953, 1953, 1051, 1064,    0, 1050, 1063,
     1052, 1052, 1062,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0, 1063, 1065, 1077, 1072, 1065, 1133,    0,

     1065, 1067,    0,    0, 1081,    0, 1116, 1080, 1133, 1067,
     1133, 1133, 1088, 1117,    0,    0,    0,    0,    0, 1119,
     1125, 1135, 1130, 1127, 1130, 1141, 1145,    0,  580, 1953,
      596,  647,  600, 1953,  606,  216,  874, 1137,    0, 1139,
     1153,    0, 1205, 1151, 1139, 1147, 1144, 1144, 1156, 1168,
     1172, 1173, 1187, 1195, 1182,    0, 1178, 1185,    0, 1182,
     1181, 1197, 1200, 1197, 1196, 1208, 1240,    0, 1197,    0,
     1192, 1953, 1193, 1953,    0, 1192, 1196, 1198, 1204, 1207,
     1214, 1249, 1233, 1252, 1267,  900,    0,    0,    0,    0,
        0,    0,    0, 1253, 1252, 1251, 1253, 1266, 1314, 1273,

      249, 1266, 1271, 1310, 1275, 1273, 1285, 1275, 1285, 1294,
     1312, 1313,    0, 1953, 1314, 1322, 1310, 1953, 1320, 1328,
     1315,    0,  822,  927, 1359, 1372, 1953,  264, 1322,  237,
     1325, 1366, 1330, 1333, 1329, 1345, 1350, 1354,    0, 1343,
        0, 1368, 1353,    0, 1367, 1361, 1373, 1353, 1365, 1406,
        0, 1372,  533, 1373, 1390,  212, 1385, 1953, 1377,    0,
     1372, 1401, 1375, 1380, 1388, 1382,    0, 1393,    0, 1409,
     1414,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0, 1411, 1411,    0,
     1415, 1407,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0, 1413, 1420, 1418, 1421, 1422,    0, 1416, 1427,
     1424, 1423, 1420, 1437, 1442, 1436, 1446, 1434, 1451,    0,
     1953, 1435, 1953, 1953, 1441, 1953, 1495, 1953, 1498, 1953,
        0, 1487, 1509, 1450, 1465, 1464, 1510, 1474, 1490, 1474,
     1485,    0, 1494,    0, 1497, 1494, 1496,    0,    0, 1513,
     1487,    0, 1530, 1492, 1499, 1953, 1487, 1502, 1500, 1515,
        0,    0, 1506, 1520, 1504,    0, 1519, 1527,    0, 1535,
     1527,    0, 1528, 1539, 1533, 1555, 1556, 1544, 1555, 1546,
        0,    0, 1557, 1543, 1544, 1553, 1546, 1560, 1567, 1953,
     1953, 1953, 1559, 1560,  715,  917, 1552, 1596, 1578, 1600,

     1568,    0, 1580,    0, 1590, 1594,    0, 1597,    0, 1583,
     1601, 1602,    0,  210,    0, 1953, 1588, 1591,    0,    0,
     1598,    0,    0, 1600,    0,    0, 1595, 1598, 1600, 1602,
     1618,    0, 1618,    0,    0,    0, 1611,    0,    0,    0,
     1605, 1616, 1625, 1614, 1607, 1621, 1614, 1614,    0, 1659,
     1637, 1643, 1632, 1953, 1654, 1652, 1649,    0, 1647,    0,
     1659,    0, 1657,    0,    0, 1660, 1667, 1648, 1662, 1656,
     1651,    0, 1672, 1699, 1679, 1677, 1664, 1665,    0,    0,
        0,    0,    0,    0, 1953, 1670, 1667, 1663, 1712,    0,
     1714, 1692, 1670, 1683, 1728, 1953, 1705, 1739, 1953, 1740,

     1715, 1742, 1711, 1703, 1714, 1750, 1757, 1732, 1729, 1729,
     1730, 1723, 1736, 1727, 1722, 1743, 1730, 1953, 1742,    0,
     1745, 1745, 1731, 1742, 1751, 1750, 1953, 1766,    0, 1757,
        0, 1762,    0, 1953, 1953, 1953, 1953, 1836, 1841, 1846,
     1851, 1856, 1861, 1866, 1871, 1876, 1879, 1884, 1889, 1892,
     1895, 1898, 1903, 1908, 1913, 1918,  119,  109, 1921, 1926,
     1931, 1936, 1939, 1942, 1947
    } ;

static yyconst flex_int16_t yy_def[766] =
    {   0,
      737,    1,  737,    3,  738,  738,  739,  739,  740,  740,
      741,  741,  742,  742,  743,  743,  740,   17,  744,  744,
      745,  745,  737,  737,  737,  737,  737,  746,  747,  748,
      749,  737,  737,  737,  737,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  737,  737,  737,  751,  750,  737,  737,
      737,  746,  748,  749,  737,  752,  752,  752,  752,  752,
      752,  752,  752,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,

      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  753,  737,  754,  755,  756,  737,  737,  737,
      737,  737,  737,  757,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  746,  746,  737,  748,  748,
      749,  749,  737,  750,  750,  750,  750,  750,  737,  750,
      750,   39,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      758,  750,  750,   53,  737,  737,  737,  737,  737,  759,
      737,  759,  737,  737,  737,  737,  737,  752,  752,   69,
      752,  752,  752,  752,   73,  737,  737,  737,  737,  737,

      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  760,  753,  753,  737,  753,  753,
      754,  754,  755,  755,  756,  737,  756,  737,  737,  761,
      737,  757,  762,  737,  737,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  758,  750,  750,  750,  737,  762,  759,
      759,  759,  737,  737,  737,  752,  752,  752,  752,  737,
      737,  737,  737,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,

      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  737,
      737,  737,  737,  737,  737,  737,  737,  764,  760,  737,
      760,  765,  761,  737,  761,  762,  762,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  759,  759,  752,  752,  752,
      737,  737,  737,  737,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,

      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  737,  737,  737,  737,  737,  737,  737,
      737,  764,  765,  765,  765,  762,  737,  762,  750,  750,
      750,  737,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  759,  759,  752,  737,  737,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,

      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      737,  737,  737,  737,  737,  737,  765,  737,  765,  737,
      750,  737,  750,  737,  737,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  737,
      750,  750,  737,  750,  759,  737,  752,  737,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  737,
      737,  737,  737,  737,  737,  750,  737,  737,  750,  737,

      750,  750,  750,  750,  750,  750,  750,  750,  750,  737,
      750,  737,  750,  759,  752,  737,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  763,  763,  763,  763,  763,
      737,  737,  737,  737,  750,  750,  750,  750,  750,  750,
      737,  750,  737,  737,  763,  763,  763,  763,  763,  763,
      763,  763,  763,  763,  763,  737,  737,  737,  737,  750,
      750,  750,  750,  737,  750,  737,  750,  737,  763,  763,
      763,  763,  763,  763,  737,  737,  737,  737,  750,  750,
      750,  737,  750,  737,  750,  737,  737,  737,  737,  737,

      750,  737,  750,  737,  750,  737,  737,  750,  737,  737,
      750,  737,  750,  737,  750,  737,  750,  737,  737,  750,
      737,  750,  737,  750,  737,  750,  737,  737,  750,  737,
      750,  737,  750,  737,  737,  737,    0,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737
    } ;

static yyconst flex_int16_t yy_nxt[2035] =
    {   0,
       24,   25,   26,   27,   25,   28,   29,   30,   31,   32,
       33,   24,   24,   34,   34,   34,   34,   34,   34,   34,
       34,   24,   24,   24,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   41,   41,   45,   46,   47,   48,
       41,   41,   49,   50,   41,   51,   52,   41,   53,   41,
       41,   54,   55,   24,   24,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   41,   41,   45,   46,   47,   48,
       41,   41,   49,   50,   41,   51,   52,   41,   53,   41,
       41,   56,  155,   57,  143,  143,  143,  143,  143,  143,
      143,  143,  145,  147,  156,  157,  158,  148,  159,  146,

      166,  167,  173,  189,   58,  175,  176,  177,  175,  226,
      227,  264,  155,  143,  143,  143,  143,  143,  143,  143,
      143,  232,  145,  147,  156,  157,  158,  148,  159,  146,
      166,  167,  173,  189,   58,   59,   60,   26,   61,   60,
       62,   59,   63,   64,   59,   59,   59,   59,   65,   65,
       65,   65,   65,   65,   65,   65,   59,   59,   59,   59,
       66,   67,   68,   69,   66,   66,   66,   66,   66,   66,
       66,   66,   66,   70,   71,   66,   66,   66,   66,   66,
       72,   66,   66,   73,   66,   66,   74,   75,   59,   59,
       66,   67,   68,   69,   66,   66,   66,   66,   66,   66,

       66,   66,   66,   70,   71,   66,   66,   66,   66,   66,
       72,   66,   66,   73,   66,   66,   77,   26,   78,   77,
       77,   26,   78,   77,   81,   26,   82,   81,   81,   26,
       82,   81,   83,  654,  181,  556,   83,   98,   26,   99,
       98,  532,  193,  194,  100,  101,  182,  102,   98,   26,
       99,   98,  330,  331,  149,  100,  101,  149,  102,  113,
       26,  114,  113,  115,  508,  116,  530,   79,  337,  117,
      181,   79,  193,  194,  337,   84,  182,  199,  207,   84,
       85,   26,   61,   85,   86,  171,   87,  337,  103,  224,
      113,   26,  114,  113,  115,  149,  116,  224,  149,  103,

      117,  222,  215,  222,   88,  215,   89,  199,  207,  134,
      118,  328,  134,  211,   90,   91,  337,   92,  172,  150,
      212,   93,   94,  126,   26,  127,  126,   95,  218,  219,
      181,   75,   96,  151,   88,  135,   89,  126,   26,  127,
      126,  118,  160,  211,   90,   91,  161,   92,  172,  150,
      212,   93,   94,  163,  268,  162,  168,   95,   85,   26,
       61,   85,   86,  151,   87,  135,  230,  164,  169,  230,
      142,  170,  160,  165,  128,  142,  161,  200,  134,  218,
      219,  178,   88,  163,   89,  162,  168,  186,  128,  236,
      186,  201,   90,   91,  237,   92,  202,  164,  169,   93,

       94,  170,  240,  165,  179,   95,  140,  200,  140,   75,
       96,  245,   88,  187,   89,  175,  176,  177,  175,  236,
      137,  201,   90,   91,  237,   92,  202,  137,  233,   93,
       94,  233,  240,  246,  179,   95,  105,   26,  106,  105,
      107,  245,  196,  187,  224,  196,  222,  108,  109,  109,
      109,  109,  109,  109,  109,  109,  109,  109,  175,  176,
      177,  175,  110,  246,  183,  184,  185,  183,  187,  175,
      176,  177,  175,  197,  198,  213,  197,  198,  213,  175,
      176,  177,  175,  175,  176,  177,  175,  111,  150,  226,
      227,  203,  110,  105,   26,  106,  105,  107,  187,  187,

      187,  187,  151,  171,  108,  109,  109,  109,  109,  109,
      109,  109,  109,  109,  109,  226,  227,  142,  150,  110,
      175,  176,  177,  175,  204,  208,  205,  209,  247,  187,
      187,  187,  151,  214,  553,  228,  214,  553,  228,  334,
      335,  248,  206,  210,  111,  175,  176,  177,  175,  110,
      119,   26,   61,  119,  204,  208,  205,  209,  247,  187,
      120,  187,  121,  121,  121,  121,  121,  121,  121,  121,
      241,  248,  206,  210,  242,  249,  122,  123,  175,  176,
      177,  175,  330,  331,  140,  217,  218,  219,  217,  187,
      137,  187,  233,  234,  235,  233,  252,  124,  330,  331,

      241,   75,  334,  335,  242,  249,  122,  123,  334,  335,
      142,  220,  229,  229,  229,  229,  229,  229,  229,  229,
      196,  196,  134,  196,  196,  134,  252,  124,  129,  130,
       26,  131,  130,  129,  129,  129,  129,  129,  129,  129,
      129,  220,  238,  243,  239,  244,  187,  187,  135,  218,
      424,  129,  129,  231,  231,  231,  231,  231,  231,  231,
      231,  231,  231,  143,  143,  143,  143,  143,  143,  143,
      143,  253,  238,  243,  239,  244,  187,  187,  135,  129,
      133,  129,  129,  129,  130,   26,  131,  130,  129,  129,
      129,  129,  129,  129,  129,  129,  144,  254,  255,  425,

      258,  253,  144,  259,  140,  137,  129,  129,  175,  176,
      177,  175,  269,  234,  235,  269,  595,  737,  250,  595,
      260,  261,  262,  263,  737,  267,  144,  254,  255,  251,
      258,  737,  144,  259,  129,  133,  129,  129,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  250,  256,
      260,  261,  262,  263,  153,  267,  257,  737,  737,  251,
      154,  134,  186,  737,  178,  186,  181,  273,  274,  275,
      273,  276,  271,  332,  218,  219,  332,  737,  737,  256,
      272,  265,  277,  188,  153,  266,  257,  179,  187,  188,
      154,  174,  174,  174,  174,  174,  174,  174,  174,  174,

      174,  276,  271,  174,  174,  174,  174,  174,  174,  737,
      272,  265,  277,  188,  737,  266,  737,  179,  187,  188,
      278,  279,  280,  196,  218,  424,  196,  197,  198,  281,
      197,  198,  282,  174,  174,  174,  174,  174,  174,  190,
      190,  190,  190,  190,  190,  190,  190,  190,  190,  187,
      278,  279,  280,  187,  187,  191,  283,  320,  321,  281,
      322,  192,  282,  213,  737,  737,  213,  273,  274,  275,
      273,  737,  323,  324,  425,  426,  427,  428,  426,  187,
      325,  326,  327,  187,  187,  191,  283,  320,  321,  187,
      322,  192,  195,  195,  195,  195,  195,  195,  195,  195,

      195,  195,  323,  324,  195,  195,  195,  195,  195,  195,
      325,  326,  327,  483,  484,  485,  486,  487,  595,  187,
      737,  595,  737,  737,  214,  228,  337,  214,  228,  218,
      424,  737,  737,  737,  195,  195,  195,  195,  195,  195,
      284,  285,  286,  287,  288,  289,  290,  291,  292,  293,
      187,  187,  294,  295,  296,  297,  298,  299,  300,  301,
      302,  303,  304,  305,  306,  307,  308,  309,  310,  311,
      312,  313,  314,  315,  316,  317,  318,  319,  737,  425,
      187,  187,  294,  295,  296,  297,  298,  299,  300,  301,
      302,  303,  304,  305,  306,  307,  308,  309,  310,  311,

      312,  313,  314,  315,  316,  317,  318,  319,  217,  218,
      219,  217,  229,  229,  229,  229,  229,  229,  229,  229,
      231,  231,  231,  231,  231,  231,  231,  231,  231,  231,
      338,  339,  340,  341,  220,  342,  343,  344,  345,  346,
      347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
      357,  358,  359,  360,  361,  362,  363,  364,  365,  737,
      338,  339,  340,  341,  220,  342,  343,  344,  345,  346,
      347,  348,  349,  350,  351,  352,  353,  354,  355,  356,
      357,  358,  359,  360,  361,  362,  363,  364,  365,  181,
      181,  368,  369,  370,  371,  372,  373,  367,  374,  376,

      377,  380,  378,  382,  394,  396,  383,  397,  384,  401,
      398,  381,  405,  412,  395,  366,  379,  737,  737,  737,
      737,  368,  369,  370,  371,  372,  373,  367,  374,  376,
      377,  380,  378,  382,  394,  396,  383,  397,  384,  401,
      398,  381,  405,  412,  395,  366,  379,  385,  386,  387,
      388,  389,  390,  391,  392,  393,  399,  413,  402,  406,
      408,  400,  403,  414,  404,  409,  407,  415,  416,  410,
      417,  418,  419,  411,  420,  421,  429,  430,  431,  737,
      435,  436,  437,  438,  439,  440,  399,  413,  402,  406,
      408,  400,  403,  414,  404,  409,  407,  415,  416,  410,

      417,  418,  419,  411,  420,  421,  429,  430,  431,  432,
      435,  436,  437,  438,  439,  440,  441,  442,  443,  444,
      445,  446,  447,  448,  449,  450,  451,  452,  453,  454,
      433,  181,  457,  737,  458,  459,  460,  461,  463,  462,
      464,  465,  466,  467,  434,  455,  441,  442,  443,  444,
      445,  446,  447,  448,  449,  450,  451,  452,  453,  454,
      433,  468,  457,  181,  458,  459,  460,  461,  463,  462,
      464,  465,  466,  467,  434,  455,  456,  469,  471,  472,
      473,  474,  475,  476,  477,  478,  479,  480,  481,  482,
      488,  468,  489,  470,  490,  491,  492,  737,  737,  737,

      737,  737,  737,  737,  737,  737,  456,  469,  471,  472,
      507,  509,  737,  510,  513,  514,  515,  516,  517,  518,
      488,  737,  489,  470,  490,  491,  492,  493,  494,  495,
      496,  497,  498,  499,  500,  501,  502,  519,  511,  520,
      507,  509,  503,  510,  513,  514,  515,  516,  517,  518,
      521,  504,  522,  523,  505,  512,  524,  506,  525,  526,
      527,  528,  529,  527,  531,  533,  536,  519,  511,  520,
      432,  537,  503,  426,  427,  428,  426,  538,  539,  540,
      521,  504,  522,  523,  505,  512,  524,  506,  525,  526,
      541,  534,  542,  543,  531,  533,  536,  544,  545,  546,

      547,  537,  548,  549,  552,  535,  737,  538,  539,  540,
      550,  425,  554,  181,  557,  555,  558,  559,  562,  563,
      541,  534,  542,  543,  337,  564,  565,  544,  545,  546,
      547,  566,  548,  549,  552,  535,  551,  560,  567,  568,
      569,  561,  554,  570,  557,  555,  558,  559,  562,  563,
      571,  572,  573,  574,  575,  564,  565,  576,  578,  579,
      580,  566,  581,  582,  583,  577,  551,  560,  567,  568,
      569,  561,  584,  570,  585,  586,  587,  588,  589,  590,
      571,  572,  573,  574,  575,  591,  597,  576,  578,  579,
      580,  532,  581,  582,  583,  577,  527,  528,  529,  527,

      592,  424,  584,  598,  585,  586,  587,  588,  589,  590,
      595,  599,  593,  595,  600,  591,  597,  550,  602,  737,
      737,  603,  181,  604,  605,  606,  607,  608,  609,  611,
      613,  553,  594,  598,  553,  737,  615,  614,  616,  617,
      618,  599,  593,  610,  619,  620,  621,  425,  602,  601,
      425,  603,  596,  604,  605,  606,  607,  608,  609,  611,
      613,  622,  594,  623,  624,  612,  615,  614,  616,  617,
      618,  625,  626,  610,  619,  620,  621,  627,  628,  601,
      629,  630,  596,  631,  632,  633,  634,  635,  636,  637,
      638,  622,  639,  623,  624,  612,  640,  641,  642,  643,

      600,  625,  626,  645,  600,  737,  646,  627,  628,  737,
      629,  630,  647,  631,  632,  633,  634,  635,  636,  637,
      638,  648,  639,  649,  650,  651,  640,  641,  642,  643,
      652,  653,  655,  645,  656,  644,  646,  657,  658,  644,
      659,  660,  647,  661,  662,  663,  664,  665,  666,  667,
      668,  648,  669,  649,  650,  651,  670,  671,  672,  673,
      652,  653,  655,  674,  656,  644,  676,  657,  658,  644,
      659,  660,  677,  661,  662,  663,  664,  665,  666,  667,
      668,  678,  669,  679,  680,  681,  670,  671,  672,  673,
      682,  683,  684,  685,  686,  675,  676,  687,  688,  689,

      690,  691,  677,  674,  693,  737,  694,  695,  696,  697,
      698,  678,  699,  679,  680,  681,  700,  704,  702,  705,
      682,  683,  684,  685,  686,  675,  706,  687,  688,  689,
      690,  691,  707,  709,  693,  692,  694,  695,  696,  697,
      698,  703,  699,  700,  700,  711,  702,  704,  737,  705,
      713,  701,  714,  715,  707,  708,  706,  717,  718,  719,
      720,  707,  721,  709,  722,  692,  723,  724,  725,  712,
      726,  703,  727,  728,  729,  711,  730,  716,  710,  710,
      713,  701,  714,  715,  716,  708,  731,  717,  718,  719,
      720,  732,  721,  733,  722,  734,  723,  724,  725,  712,

      726,  735,  727,  728,  729,  736,  730,  716,  710,  710,
      737,  737,  737,  737,  716,  737,  731,  737,  737,  737,
      737,  732,  737,  733,  737,  734,  737,  737,  737,  737,
      737,  735,  737,  737,  737,  736,   76,   76,   76,   76,
       76,   80,   80,   80,   80,   80,   59,   59,   59,   59,
       59,   97,   97,   97,   97,   97,  104,  104,  104,  104,
      104,  112,  112,  112,  112,  112,  125,  125,  125,  125,
      125,  132,  132,  132,  132,  132,  136,  737,  136,  136,
      136,  138,  737,  138,  139,  737,  139,  139,  139,  141,
      737,  141,  141,  141,  144,  737,  144,  180,  180,  180,

      188,  737,  188,  216,  216,  216,  216,  216,  221,  737,
      221,  221,  221,  223,  737,  223,  223,  223,  225,  225,
      225,  225,  225,  270,  270,  270,  329,  329,  329,  329,
      329,  333,  333,  333,  333,  333,  336,  737,  336,  336,
      336,  375,  737,  375,  422,  737,  422,  423,  423,  423,
      423,  423,   23,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,

      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737
    } ;

static yyconst flex_int16_t yy_chk[2035] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,   40,    2,   34,   34,   34,   34,   34,   34,
       34,   34,   36,   37,   42,   43,   44,   37,   45,   36,

       48,   49,   52,   67,    2,   55,   55,   55,   55,  117,
      117,  758,   40,   65,   65,   65,   65,   65,   65,   65,
       65,  757,   36,   37,   42,   43,   44,   37,   45,   36,
       48,   49,   52,   67,    2,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    5,    5,    5,    5,
        6,    6,    6,    6,    7,    7,    7,    7,    8,    8,
        8,    8,    7,  614,   57,  456,    8,   11,   11,   11,
       11,  430,   70,   71,   11,   11,   57,   11,   12,   12,
       12,   12,  215,  215,   68,   12,   12,   68,   12,   15,
       15,   15,   15,   15,  401,   15,  428,    5,  336,   15,
      270,    6,   70,   71,  269,    7,   57,   88,   92,    8,
        9,    9,    9,    9,    9,   51,    9,  233,   11,  224,
       16,   16,   16,   16,   16,   38,   16,  223,   38,   12,

       16,  222,  110,  221,    9,  110,    9,   88,   92,   25,
       15,  212,   25,   94,    9,    9,  428,    9,   51,   38,
       95,    9,    9,   19,   19,   19,   19,    9,  216,  216,
      180,    9,    9,   38,    9,   25,    9,   20,   20,   20,
       20,   16,   46,   94,    9,    9,   46,    9,   51,   38,
       95,    9,    9,   47,  177,   46,   50,    9,   10,   10,
       10,   10,   10,   38,   10,   25,  122,   47,   50,  122,
      142,   50,   46,   47,   19,  141,   46,   89,   56,  219,
      219,   56,   10,   47,   10,   46,   50,   60,   20,  145,
       60,   89,   10,   10,  146,   10,   89,   47,   50,   10,

       10,   50,  148,   47,   56,   10,  140,   89,  139,   10,
       10,  153,   10,   60,   10,   75,   75,   75,   75,  145,
      137,   89,   10,   10,  146,   10,   89,  136,  187,   10,
       10,  187,  148,  155,   56,   10,   13,   13,   13,   13,
       13,  153,   77,   60,  116,   77,  115,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   79,   79,
       79,   79,   13,  155,   58,   58,   58,   58,   77,   84,
       84,   84,   84,   81,   85,   98,   81,   85,   98,  103,
      103,  103,  103,  111,  111,  111,  111,   13,   58,  225,
      225,   90,   13,   14,   14,   14,   14,   14,   77,   81,

       85,   98,   58,   72,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,  227,  227,   64,   58,   14,
      118,  118,  118,  118,   91,   93,   91,   93,  156,   81,
       85,   98,   58,  105,  453,  119,  105,  453,  119,  230,
      230,  157,   91,   93,   14,  128,  128,  128,  128,   14,
       17,   17,   17,   17,   91,   93,   91,   93,  156,  105,
       17,  119,   17,   17,   17,   17,   17,   17,   17,   17,
      150,  157,   91,   93,  150,  158,   17,   17,  133,  133,
      133,  133,  329,  329,   63,  113,  113,  113,  113,  105,
       62,  119,  135,  135,  135,  135,  160,   17,  331,  331,

      150,   17,  333,  333,  150,  158,   17,   17,  335,  335,
       31,  113,  121,  121,  121,  121,  121,  121,  121,  121,
      126,  130,  134,  126,  130,  134,  160,   17,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,  113,  147,  151,  147,  151,  126,  130,  134,  332,
      332,   21,   21,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  143,  143,  143,  143,  143,  143,  143,
      143,  161,  147,  151,  147,  151,  126,  130,  134,   21,
       21,   21,   21,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,  152,  162,  163,  332,

      165,  161,  152,  166,   30,   28,   22,   22,  175,  175,
      175,  175,  179,  179,  179,  179,  595,   23,  159,  595,
      167,  168,  169,  170,    0,  173,  152,  162,  163,  159,
      165,    0,  152,  166,   22,   22,   22,   22,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,  159,  164,
      167,  168,  169,  170,   39,  173,  164,    0,    0,  159,
       39,  178,  186,    0,  178,  186,  182,  183,  183,  183,
      183,  189,  182,  220,  220,  220,  220,    0,    0,  164,
      182,  172,  191,  190,   39,  172,  164,  178,  186,  190,
       39,   53,   53,   53,   53,   53,   53,   53,   53,   53,

       53,  189,  182,   53,   53,   53,   53,   53,   53,    0,
      182,  172,  191,  190,    0,  172,    0,  178,  186,  190,
      193,  194,  199,  196,  423,  423,  196,  197,  198,  200,
      197,  198,  201,   53,   53,   53,   53,   53,   53,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,  196,
      193,  194,  199,  197,  198,   69,  202,  204,  205,  200,
      206,   69,  201,  213,    0,    0,  213,  273,  273,  273,
      273,    0,  207,  208,  423,  337,  337,  337,  337,  196,
      209,  210,  211,  197,  198,   69,  202,  204,  205,  213,
      206,   69,   73,   73,   73,   73,   73,   73,   73,   73,

       73,   73,  207,  208,   73,   73,   73,   73,   73,   73,
      209,  210,  211,  386,  386,  386,  386,  386,  596,  213,
        0,  596,    0,    0,  214,  228,  337,  214,  228,  424,
      424,    0,    0,    0,   73,   73,   73,   73,   73,   73,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      214,  228,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,    0,  424,
      214,  228,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,

      203,  203,  203,  203,  203,  203,  203,  203,  217,  217,
      217,  217,  229,  229,  229,  229,  229,  229,  229,  229,
      231,  231,  231,  231,  231,  231,  231,  231,  231,  231,
      237,  238,  239,  240,  217,  241,  242,  243,  244,  245,
      246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
      256,  257,  259,  260,  261,  262,  263,  266,  267,    0,
      237,  238,  239,  240,  217,  241,  242,  243,  244,  245,
      246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
      256,  257,  259,  260,  261,  262,  263,  266,  267,  271,
      272,  276,  277,  279,  280,  281,  282,  272,  283,  294,

      295,  297,  296,  298,  301,  302,  298,  305,  298,  308,
      305,  297,  310,  313,  301,  271,  296,    0,    0,    0,
        0,  276,  277,  279,  280,  281,  282,  272,  283,  294,
      295,  297,  296,  298,  301,  302,  298,  305,  298,  308,
      305,  297,  310,  313,  301,  271,  296,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  307,  314,  309,  311,
      312,  307,  309,  320,  309,  312,  311,  321,  322,  312,
      323,  324,  325,  312,  326,  327,  338,  340,  341,    0,
      344,  345,  346,  347,  348,  349,  307,  314,  309,  311,
      312,  307,  309,  320,  309,  312,  311,  321,  322,  312,

      323,  324,  325,  312,  326,  327,  338,  340,  341,  343,
      344,  345,  346,  347,  348,  349,  350,  351,  352,  353,
      354,  355,  357,  358,  360,  361,  362,  363,  364,  365,
      343,  366,  369,    0,  371,  373,  376,  377,  378,  377,
      379,  379,  379,  380,  343,  366,  350,  351,  352,  353,
      354,  355,  357,  358,  360,  361,  362,  363,  364,  365,
      343,  381,  369,  367,  371,  373,  376,  377,  378,  377,
      379,  379,  379,  380,  343,  366,  367,  382,  383,  384,
      385,  385,  385,  385,  385,  385,  385,  385,  385,  385,
      394,  381,  395,  382,  396,  397,  398,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  367,  382,  383,  384,
      400,  402,    0,  403,  405,  406,  407,  408,  409,  410,
      394,    0,  395,  382,  396,  397,  398,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  411,  404,  412,
      400,  402,  399,  403,  405,  406,  407,  408,  409,  410,
      415,  399,  416,  417,  399,  404,  419,  399,  420,  421,
      425,  425,  425,  425,  429,  431,  433,  411,  404,  412,
      432,  434,  399,  426,  426,  426,  426,  435,  436,  437,
      415,  399,  416,  417,  399,  404,  419,  399,  420,  421,
      438,  432,  440,  442,  429,  431,  433,  443,  445,  446,

      447,  434,  448,  449,  452,  432,    0,  435,  436,  437,
      450,  425,  454,  455,  457,  455,  459,  461,  463,  464,
      438,  432,  440,  442,  426,  465,  466,  443,  445,  446,
      447,  468,  448,  449,  452,  432,  450,  462,  470,  471,
      488,  462,  454,  489,  457,  455,  459,  461,  463,  464,
      491,  492,  503,  504,  505,  465,  466,  506,  507,  509,
      510,  468,  511,  512,  513,  506,  450,  462,  470,  471,
      488,  462,  514,  489,  515,  516,  517,  518,  519,  522,
      491,  492,  503,  504,  505,  525,  534,  506,  507,  509,
      510,  532,  511,  512,  513,  506,  527,  527,  527,  527,

      529,  529,  514,  535,  515,  516,  517,  518,  519,  522,
      533,  536,  532,  533,  537,  525,  534,  550,  538,    0,
        0,  539,  555,  540,  541,  543,  545,  546,  547,  551,
      554,  553,  532,  535,  553,    0,  557,  555,  558,  559,
      560,  536,  532,  550,  563,  564,  565,  527,  538,  537,
      529,  539,  533,  540,  541,  543,  545,  546,  547,  551,
      554,  567,  532,  568,  570,  553,  557,  555,  558,  559,
      560,  571,  573,  550,  563,  564,  565,  574,  575,  537,
      576,  577,  533,  578,  579,  580,  583,  584,  585,  586,
      587,  567,  588,  568,  570,  553,  589,  593,  594,  597,

      598,  571,  573,  599,  600,    0,  601,  574,  575,    0,
      576,  577,  603,  578,  579,  580,  583,  584,  585,  586,
      587,  605,  588,  606,  608,  610,  589,  593,  594,  597,
      611,  612,  617,  599,  618,  598,  601,  621,  624,  600,
      627,  628,  603,  629,  630,  631,  633,  637,  641,  642,
      643,  605,  644,  606,  608,  610,  645,  646,  647,  648,
      611,  612,  617,  650,  618,  598,  651,  621,  624,  600,
      627,  628,  652,  629,  630,  631,  633,  637,  641,  642,
      643,  653,  644,  655,  656,  657,  645,  646,  647,  648,
      659,  661,  663,  666,  667,  650,  651,  668,  669,  670,

      671,  673,  652,  674,  675,    0,  676,  677,  678,  686,
      687,  653,  688,  655,  656,  657,  689,  692,  691,  693,
      659,  661,  663,  666,  667,  650,  694,  668,  669,  670,
      671,  673,  695,  697,  675,  674,  676,  677,  678,  686,
      687,  691,  688,  698,  700,  701,  702,  692,    0,  693,
      703,  689,  704,  705,  706,  695,  694,  708,  709,  710,
      711,  707,  712,  697,  713,  674,  714,  715,  716,  702,
      717,  691,  719,  721,  722,  701,  723,  706,  698,  700,
      703,  689,  704,  705,  707,  695,  724,  708,  709,  710,
      711,  725,  712,  726,  713,  728,  714,  715,  716,  702,

      717,  730,  719,  721,  722,  732,  723,  706,  698,  700,
        0,    0,    0,    0,  707,    0,  724,    0,    0,    0,
        0,  725,    0,  726,    0,  728,    0,    0,    0,    0,
        0,  730,    0,    0,    0,  732,  738,  738,  738,  738,
      738,  739,  739,  739,  739,  739,  740,  740,  740,  740,
      740,  741,  741,  741,  741,  741,  742,  742,  742,  742,
      742,  743,  743,  743,  743,  743,  744,  744,  744,  744,
      744,  745,  745,  745,  745,  745,  746,    0,  746,  746,
      746,  747,    0,  747,  748,    0,  748,  748,  748,  749,
        0,  749,  749,  749,  750,    0,  750,  751,  751,  751,

      752,    0,  752,  753,  753,  753,  753,  753,  754,    0,
      754,  754,  754,  755,    0,  755,  755,  755,  756,  756,
      756,  756,  756,  759,  759,  759,  760,  760,  760,  760,
      760,  761,  761,  761,  761,  761,  762,    0,  762,  762,
      762,  763,    0,  763,  764,    0,  764,  765,  765,  765,
      765,  765,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,

      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737,  737,  737,  737,  737,  737,  737,
      737,  737,  737,  737
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lex.l"
#line 2 "lex.l"
/* lex.l: Lex parser for Keyman keyboard source files for kmflcomp compiler */

/* Derived from version written by David Gardner for k_tty */

#include <stdio.h>
#include <stdlib.h>

#include "compiler.h"
#include "yacc.h"

void yyerror(char *);

#if defined(FLEX_SCANNER) && ! defined(INITIAL)
int caller=0,caller0=0;
#else
int caller= INITIAL,caller0=INITIAL;
#endif

char qchar;
extern int lineno;
extern int errcount;
int done=0;

void yycleanup(void)
{
    yy_delete_buffer(YY_CURRENT_BUFFER);
}

int yyterminate(void)
{
	yyerror("END\n");
	fflush(stderr); 
	return YY_NULL;
}











#line 1203 "lex.c"

#define INITIAL 0
#define STOR 1
#define QUOTE 2
#define PARENS 3
#define KEYNAME 4
#define PLIST 5
#define KBDVER 6
#define BITMAP 7
#define LNGCODE 8
#define SKIP 9
#define NAME 10

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 53 "lex.l"


#line 1372 "lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 738 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1953 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 55 "lex.l"
{lineno++;caller=INITIAL;BEGIN(INITIAL);return(TOK_NL);}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 56 "lex.l"
{/* just ignore carriage returns */};
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(STOR):
case YY_STATE_EOF(QUOTE):
case YY_STATE_EOF(PARENS):
case YY_STATE_EOF(KEYNAME):
case YY_STATE_EOF(PLIST):
case YY_STATE_EOF(KBDVER):
case YY_STATE_EOF(BITMAP):
case YY_STATE_EOF(LNGCODE):
case YY_STATE_EOF(SKIP):
case YY_STATE_EOF(NAME):
#line 58 "lex.l"
{
				if(done){yyterminate();}
				else    {done=1;lineno++;caller=INITIAL;BEGIN(INITIAL);return(TOK_NL);}
			}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 63 "lex.l"
{return TOK_NAME;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 64 "lex.l"
{BEGIN(BITMAP);return TOK_BITMAP;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 65 "lex.l"
{caller=STOR;BEGIN(STOR);return TOK_HOTKEY;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 66 "lex.l"
{BEGIN(KBDVER);return TOK_VERSION;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 67 "lex.l"
{BEGIN(LNGCODE);return TOK_LANGUAGE;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 68 "lex.l"
{return TOK_LAYOUT;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 69 "lex.l"
{return TOK_CAPSOFF;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 70 "lex.l"
{return TOK_CAPSON;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 71 "lex.l"
{return TOK_CAPSFREE;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 72 "lex.l"
{return TOK_COPYRIGHT;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 73 "lex.l"
{return TOK_MESSAGE;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 74 "lex.l"
{return TOK_MNEMONIC;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 75 "lex.l"
{return TOK_ETHNOLOGUE;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 76 "lex.l"
{return TOK_AUTHOR;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 77 "lex.l"
{return TOK_ANSI;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 78 "lex.l"
{return TOK_UNICODE;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 79 "lex.l"
{return TOK_ANSI;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 80 "lex.l"
{caller=STOR;BEGIN(STOR);return TOK_STORE;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 81 "lex.l"
{return TOK_OUTS;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 82 "lex.l"
{return TOK_GROUP;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 83 "lex.l"
{return TOK_USINGKEYS;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 84 "lex.l"
{return TOK_USE;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 85 "lex.l"
{return TOK_CONTEXT;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 86 "lex.l"
{return TOK_ANY;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 87 "lex.l"
{return TOK_NOTANY;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 88 "lex.l"
{return TOK_BEEP;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 89 "lex.l"
{BEGIN(PLIST);return TOK_INDEX;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 90 "lex.l"
{return TOK_NOMATCH;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 91 "lex.l"
{return TOK_MATCH;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 92 "lex.l"
{return TOK_NUL;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 93 "lex.l"
{return TOK_DEADKEY;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 94 "lex.l"
{return TOK_DEADKEY;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 95 "lex.l"
{return TOK_RTN;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 96 "lex.l"
{return TOK_CALL;  /* not implemented */}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 97 "lex.l"
{return TOK_SWITCH;/*  (obsolete) */}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 98 "lex.l"
{return TOK_GT;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 99 "lex.l"
{return TOK_PLUS;}
	YY_BREAK
case 40:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 100 "lex.l"
{BEGIN(NAME);return TOK_DOLLAR;}
	YY_BREAK

case 41:
YY_RULE_SETUP
#line 103 "lex.l"
{/* ignore spaces */} 
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 104 "lex.l"
{BEGIN(SKIP);}
	YY_BREAK
case 43:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 105 "lex.l"
{BEGIN(PARENS);return(TOK_BRKT);}
	YY_BREAK
case 44:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 106 "lex.l"
{qchar='\'';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 45:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 107 "lex.l"
{qchar='"';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 108 "lex.l"
{yylval.number=strtol(yytext,NULL,8);return(TOK_NUMBER);}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 109 "lex.l"
{yylval.number=atoi(yytext+1);return(TOK_NUMBER);}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 110 "lex.l"
{yylval.number=strtol(yytext+1,NULL,16);return(TOK_NUMBER);}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 111 "lex.l"
{yylval.number=strtol(yytext+2,NULL,16);return(TOK_NUMBER);}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 112 "lex.l"
{BEGIN(KEYNAME);return(TOK_SB);}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 113 "lex.l"
{return(TOK_BEEP);}
	YY_BREAK


case 52:
YY_RULE_SETUP
#line 117 "lex.l"
{return(TOK_DEADKEY);}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 118 "lex.l"
{return(TOK_DEADKEY);}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 119 "lex.l"
{return(TOK_OUTS);}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 120 "lex.l"
{return(TOK_NUL);}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 121 "lex.l"
{return(TOK_ERROR);}
	YY_BREAK


case 57:
YY_RULE_SETUP
#line 125 "lex.l"
{/* ignore spaces */}
	YY_BREAK
case 58:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 126 "lex.l"
{/* ignore comments */}
	YY_BREAK
case 59:
/* rule 59 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 127 "lex.l"
{/* before either EOL */}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 128 "lex.l"
{return TOK_QM;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 129 "lex.l"
{yylval.number=*yytext;return TOK_CHAR;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 130 "lex.l"
{yylval.number=*yytext;return TOK_CHAR;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 131 "lex.l"
{BEGIN(SKIP);}
	YY_BREAK


case 64:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 135 "lex.l"
{/* ignore anything after a space */}
	YY_BREAK
case 65:
/* rule 65 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 136 "lex.l"
{/* including comments */}
	YY_BREAK
case 66:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 137 "lex.l"
{qchar='\'';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 67:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 138 "lex.l"
{qchar='"';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 139 "lex.l"
{yylval.number=*yytext;return TOK_CHAR;}
	YY_BREAK
case 69:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 140 "lex.l"
{/* also ignore anything after a comma */}
	YY_BREAK
case 70:
/* rule 70 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 141 "lex.l"
{/* before either EOL */}
	YY_BREAK


case 71:
YY_RULE_SETUP
#line 145 "lex.l"
{/* ignore spaces */}
	YY_BREAK
case 72:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 146 "lex.l"
{/* ignore comments */}
	YY_BREAK
case 73:
/* rule 73 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 147 "lex.l"
{/* before either EOL */}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 148 "lex.l"
{yylval.number=strtoul(yytext,NULL,8);return(TOK_NUMBER);}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 149 "lex.l"
{yylval.number=strtoul(yytext+1,NULL,10);return(TOK_NUMBER);}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 150 "lex.l"
{yylval.number=strtoul(yytext+1,NULL,16);return(TOK_NUMBER);}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 151 "lex.l"
{/* ignore comma separator */}
	YY_BREAK


case 78:
YY_RULE_SETUP
#line 155 "lex.l"
{if (*yytext==qchar) 
					{BEGIN(caller);return(TOK_QM);} 
				else 
					{yylval.number=*yytext;return(TOK_CHAR);}
				}
	YY_BREAK


case 79:
YY_RULE_SETUP
#line 163 "lex.l"

	YY_BREAK
case 80:
YY_RULE_SETUP
#line 164 "lex.l"
{BEGIN(caller);return(TOK_BRKT);} 
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 165 "lex.l"
{yylval.number=*yytext;return(TOK_CHAR);}
	YY_BREAK


case 82:
YY_RULE_SETUP
#line 169 "lex.l"
{/* ignore */}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 170 "lex.l"
{ return(TOK_COMMA);}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 171 "lex.l"
{ return(TOK_BRKT);}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 172 "lex.l"
{BEGIN(caller);return(TOK_BRKT);}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 173 "lex.l"
{yylval.number=*yytext;return(TOK_CHAR);}
	YY_BREAK


case 87:
YY_RULE_SETUP
#line 177 "lex.l"
{yylval.number=*yytext;return(TOK_CHAR);}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 178 "lex.l"
{BEGIN(caller);}
	YY_BREAK


case 89:
YY_RULE_SETUP
#line 182 "lex.l"
{/* ignore */}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 183 "lex.l"
{yylval.number=KS_LSHIFT;return(TOK_SHIFT);}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 184 "lex.l"
{yylval.number=KS_CAPS;return(TOK_SHIFT);}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 185 "lex.l"
{yylval.number=KS_LCTRL;return(TOK_SHIFT);}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 186 "lex.l"
{yylval.number=KS_LALT;return(TOK_SHIFT);}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 187 "lex.l"
{yylval.number=KS_RSHIFT;return(TOK_SHIFT);}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 188 "lex.l"
{yylval.number=KS_NCAPS;return(TOK_SHIFT);}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 189 "lex.l"
{yylval.number=KS_RCTRL;return(TOK_SHIFT);}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 190 "lex.l"
{yylval.number=KS_RALT;return(TOK_SHIFT);}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 191 "lex.l"
{yylval.number=KS_SHIFT;return(TOK_SHIFT);}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 192 "lex.l"
{yylval.number=KS_CTRL;return(TOK_SHIFT);}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 193 "lex.l"
{yylval.number=KS_ALT;return(TOK_SHIFT);}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 195 "lex.l"
{yylval.number=0x20;return(TOK_RAWKEY);}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 196 "lex.l"
{yylval.number=0x27;return(TOK_RAWKEY);}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 197 "lex.l"
{yylval.number=0x30;return(TOK_RAWKEY);}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 198 "lex.l"
{yylval.number=0x31;return(TOK_RAWKEY);}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 199 "lex.l"
{yylval.number=0x32;return(TOK_RAWKEY);}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 200 "lex.l"
{yylval.number=0x33;return(TOK_RAWKEY);}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 201 "lex.l"
{yylval.number=0x34;return(TOK_RAWKEY);}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 202 "lex.l"
{yylval.number=0x35;return(TOK_RAWKEY);}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 203 "lex.l"
{yylval.number=0x36;return(TOK_RAWKEY);}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 204 "lex.l"
{yylval.number=0x37;return(TOK_RAWKEY);}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 205 "lex.l"
{yylval.number=0x38;return(TOK_RAWKEY);}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 206 "lex.l"
{yylval.number=0x39;return(TOK_RAWKEY);}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 207 "lex.l"
{yylval.number=0x41;return(TOK_RAWKEY);}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 208 "lex.l"
{yylval.number=0x42;return(TOK_RAWKEY);}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 209 "lex.l"
{yylval.number=0x43;return(TOK_RAWKEY);}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 210 "lex.l"
{yylval.number=0x44;return(TOK_RAWKEY);}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 211 "lex.l"
{yylval.number=0x45;return(TOK_RAWKEY);}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 212 "lex.l"
{yylval.number=0x46;return(TOK_RAWKEY);}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 213 "lex.l"
{yylval.number=0x47;return(TOK_RAWKEY);}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 214 "lex.l"
{yylval.number=0x48;return(TOK_RAWKEY);}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 215 "lex.l"
{yylval.number=0x49;return(TOK_RAWKEY);}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 216 "lex.l"
{yylval.number=0x4a;return(TOK_RAWKEY);}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 217 "lex.l"
{yylval.number=0x4b;return(TOK_RAWKEY);}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 218 "lex.l"
{yylval.number=0x4c;return(TOK_RAWKEY);}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 219 "lex.l"
{yylval.number=0x4d;return(TOK_RAWKEY);}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 220 "lex.l"
{yylval.number=0x4e;return(TOK_RAWKEY);}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 221 "lex.l"
{yylval.number=0x4f;return(TOK_RAWKEY);}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 222 "lex.l"
{yylval.number=0x50;return(TOK_RAWKEY);}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 223 "lex.l"
{yylval.number=0x51;return(TOK_RAWKEY);}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 224 "lex.l"
{yylval.number=0x52;return(TOK_RAWKEY);}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 225 "lex.l"
{yylval.number=0x53;return(TOK_RAWKEY);}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 226 "lex.l"
{yylval.number=0x54;return(TOK_RAWKEY);}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 227 "lex.l"
{yylval.number=0x55;return(TOK_RAWKEY);}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 228 "lex.l"
{yylval.number=0x56;return(TOK_RAWKEY);}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 229 "lex.l"
{yylval.number=0x57;return(TOK_RAWKEY);}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 230 "lex.l"
{yylval.number=0x58;return(TOK_RAWKEY);}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 231 "lex.l"
{yylval.number=0x59;return(TOK_RAWKEY);}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 232 "lex.l"
{yylval.number=0x5a;return(TOK_RAWKEY);}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 233 "lex.l"
{yylval.number=0x60;return(TOK_RAWKEY);}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 234 "lex.l"
{yylval.number=0x2c;return(TOK_RAWKEY);}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 235 "lex.l"
{yylval.number=0x2d;return(TOK_RAWKEY);}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 236 "lex.l"
{yylval.number=0x2e;return(TOK_RAWKEY);}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 237 "lex.l"
{yylval.number=0x2f;return(TOK_RAWKEY);}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 238 "lex.l"
{yylval.number=0x3a;return(TOK_RAWKEY);}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 239 "lex.l"
{yylval.number=0x3d;return(TOK_RAWKEY);}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 240 "lex.l"
{yylval.number=0x5b;return(TOK_RAWKEY);}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 241 "lex.l"
{yylval.number=0x5c;return(TOK_RAWKEY);}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 242 "lex.l"
{yylval.number=0x5d;return(TOK_RAWKEY);}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 243 "lex.l"
{yylval.number=0xff08;return(TOK_RAWKEY);}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 244 "lex.l"
{yylval.number=0xff09;return(TOK_RAWKEY);}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 245 "lex.l"
{yylval.number=0xff0d;return(TOK_RAWKEY);}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 246 "lex.l"
{yylval.number=0xff13;return(TOK_RAWKEY);}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 247 "lex.l"
{yylval.number=0xff14;return(TOK_RAWKEY);}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 248 "lex.l"
{yylval.number=0xff1b;return(TOK_RAWKEY);}
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 249 "lex.l"
{yylval.number=0xff50;return(TOK_RAWKEY);}
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 250 "lex.l"
{yylval.number=0xff51;return(TOK_RAWKEY);}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 251 "lex.l"
{yylval.number=0xff52;return(TOK_RAWKEY);}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 252 "lex.l"
{yylval.number=0xff53;return(TOK_RAWKEY);}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 253 "lex.l"
{yylval.number=0xff54;return(TOK_RAWKEY);}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 254 "lex.l"
{yylval.number=0xff55;return(TOK_RAWKEY);}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 255 "lex.l"
{yylval.number=0xff56;return(TOK_RAWKEY);}
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 256 "lex.l"
{yylval.number=0xff57;return(TOK_RAWKEY);}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 257 "lex.l"
{yylval.number=0xff63;return(TOK_RAWKEY);}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 258 "lex.l"
{yylval.number=0xff7f;return(TOK_RAWKEY);}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 259 "lex.l"
{yylval.number=0xffaa;return(TOK_RAWKEY);}
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 260 "lex.l"
{yylval.number=0xffab;return(TOK_RAWKEY);}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 261 "lex.l"
{yylval.number=0xffad;return(TOK_RAWKEY);}
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 262 "lex.l"
{yylval.number=0xffae;return(TOK_RAWKEY);}
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 263 "lex.l"
{yylval.number=0xffaf;return(TOK_RAWKEY);}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 264 "lex.l"
{yylval.number=0xffb0;return(TOK_RAWKEY);}
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 265 "lex.l"
{yylval.number=0xffb1;return(TOK_RAWKEY);}
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 266 "lex.l"
{yylval.number=0xffb2;return(TOK_RAWKEY);}
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 267 "lex.l"
{yylval.number=0xffb3;return(TOK_RAWKEY);}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 268 "lex.l"
{yylval.number=0xffb4;return(TOK_RAWKEY);}
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 269 "lex.l"
{yylval.number=0xffb5;return(TOK_RAWKEY);}
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 270 "lex.l"
{yylval.number=0xffb6;return(TOK_RAWKEY);}
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 271 "lex.l"
{yylval.number=0xffb7;return(TOK_RAWKEY);}
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 272 "lex.l"
{yylval.number=0xffb8;return(TOK_RAWKEY);}
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 273 "lex.l"
{yylval.number=0xffb9;return(TOK_RAWKEY);}
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 274 "lex.l"
{yylval.number=0xffbe;return(TOK_RAWKEY);}
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 275 "lex.l"
{yylval.number=0xffbf;return(TOK_RAWKEY);}
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 276 "lex.l"
{yylval.number=0xffc0;return(TOK_RAWKEY);}
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 277 "lex.l"
{yylval.number=0xffc1;return(TOK_RAWKEY);}
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 278 "lex.l"
{yylval.number=0xffc2;return(TOK_RAWKEY);}
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 279 "lex.l"
{yylval.number=0xffc3;return(TOK_RAWKEY);}
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 280 "lex.l"
{yylval.number=0xffc4;return(TOK_RAWKEY);}
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 281 "lex.l"
{yylval.number=0xffc5;return(TOK_RAWKEY);}
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 282 "lex.l"
{yylval.number=0xffc6;return(TOK_RAWKEY);}
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 283 "lex.l"
{yylval.number=0xffc7;return(TOK_RAWKEY);}
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 284 "lex.l"
{yylval.number=0xffc8;return(TOK_RAWKEY);}
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 285 "lex.l"
{yylval.number=0xffc9;return(TOK_RAWKEY);}
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 286 "lex.l"
{yylval.number=0xffca;return(TOK_RAWKEY);}
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 287 "lex.l"
{yylval.number=0xffcb;return(TOK_RAWKEY);}
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 288 "lex.l"
{yylval.number=0xffcc;return(TOK_RAWKEY);}
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 289 "lex.l"
{yylval.number=0xffcd;return(TOK_RAWKEY);}
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 290 "lex.l"
{yylval.number=0xffce;return(TOK_RAWKEY);}
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 291 "lex.l"
{yylval.number=0xffcf;return(TOK_RAWKEY);}
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 292 "lex.l"
{yylval.number=0xffd0;return(TOK_RAWKEY);}
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 293 "lex.l"
{yylval.number=0xffd1;return(TOK_RAWKEY);}
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 294 "lex.l"
{yylval.number=0xffd2;return(TOK_RAWKEY);}
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 295 "lex.l"
{yylval.number=0xffd3;return(TOK_RAWKEY);}
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 296 "lex.l"
{yylval.number=0xffd4;return(TOK_RAWKEY);}
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 297 "lex.l"
{yylval.number=0xffd5;return(TOK_RAWKEY);}
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 298 "lex.l"
{yylval.number=0xffe1;return(TOK_RAWKEY);}
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 299 "lex.l"
{yylval.number=0xffe3;return(TOK_RAWKEY);}
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 300 "lex.l"
{yylval.number=0xffe5;return(TOK_RAWKEY);}
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 301 "lex.l"
{yylval.number=0xffe9;return(TOK_RAWKEY);}
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 302 "lex.l"
{yylval.number=0xffff;return(TOK_RAWKEY);}
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 303 "lex.l"
{yylval.number=0x3c;return(TOK_RAWKEY); /* on German kbds only!*/}
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 305 "lex.l"
{yylval.number=text_to_keysym(yytext); if (yylval.number == -1) yyerror("unrecognised raw key"); else return(TOK_XKEYSYM);}
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 306 "lex.l"
{ yyerror("unrecognised raw key");} 
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 307 "lex.l"
{caller0=caller;caller=KEYNAME;qchar='\'';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 308 "lex.l"
{caller0=caller;caller=KEYNAME;qchar='\"';BEGIN(QUOTE);return(TOK_QM);}
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 310 "lex.l"
{
					if(caller==KEYNAME) caller=caller0;
					BEGIN(caller);return(TOK_SB);
				} 
	YY_BREAK

case 215:
/* rule 215 can match eol */
YY_RULE_SETUP
#line 316 "lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 216:
/* rule 216 can match eol */
YY_RULE_SETUP
#line 317 "lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 217:
/* rule 217 can match eol */
YY_RULE_SETUP
#line 318 "lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 218:
/* rule 218 can match eol */
YY_RULE_SETUP
#line 319 "lex.l"
{lineno++;	/* Join lines */}
	YY_BREAK
case 219:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 321 "lex.l"
{/* ignore, use both /\r and /\n, not to work $ */}
	YY_BREAK
case 220:
/* rule 220 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 322 "lex.l"
{/*   with either CR or CR/LF line ending */}
	YY_BREAK
case 221:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 323 "lex.l"
{/* ignore */}
	YY_BREAK
case 222:
/* rule 222 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 324 "lex.l"
{/* ignore */}
	YY_BREAK
case 223:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 325 "lex.l"
{/* ignore */}
	YY_BREAK
case 224:
/* rule 224 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 326 "lex.l"
{/* ignore */}
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 328 "lex.l"
{BEGIN(SKIP);}
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 330 "lex.l"
{/* Keyman platform conditional - just drop marker */}
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 331 "lex.l"
{/* Kmfl platform conditional - just drop marker */}
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 332 "lex.l"
{BEGIN(SKIP);} /* Platform Conditional */
	YY_BREAK

case 229:
YY_RULE_SETUP
#line 335 "lex.l"
{/* ignore everything until nl or EOF */}
	YY_BREAK

case 230:
YY_RULE_SETUP
#line 338 "lex.l"
{fprintf(stderr,"Line %d: Unmatched closing parenthesis\n",lineno);return(TOK_BRKT);}
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 339 "lex.l"
{yylval.number=yytext[0];fprintf(stderr,"Line %d: Unrecognized keyword '%s'\n", 
					(int)lineno, yytext);errcount++;return(TOK_ERROR);}
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 341 "lex.l"
{yylval.number=yytext[0];fprintf(stderr,"Line %d: Unexpected char (%d) `%c'\n", 
					(int)lineno, (int) yytext[0],(char) yytext[0]);errcount++;return(TOK_CHAR);}
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 343 "lex.l"
ECHO;
	YY_BREAK
#line 2741 "lex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 738 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 738 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 737);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 343 "lex.l"
